@@ -30,7 +30,7 @@ except ImportError:
 
 import objc
 from Foundation import NSURL, NSURLTypeIdentifierKey
-from UniformTypeIdentifiers import UTType, UTTypeImage, UTTypeMovie
+from utitools import conforms_to_uti, uti_for_path
 
 logger = logging.getLogger("osxphotos")
 
@@ -41,18 +41,8 @@ EDITED_RE = r"^.*\/?[A-Za-z]{3}_E\d{4}.*$"
 
 
 def file_conforms_to_uti(path: str | os.PathLike, uti: str) -> bool:
-    file_url = NSURL.fileURLWithPath_(str(path))
-    resource_values, error = file_url.resourceValuesForKeys_error_(
-        [NSURLTypeIdentifierKey], None
-    )
-    if error:
-        raise ValueError(f"Error getting file type: {error}")
-    file_type = resource_values[NSURLTypeIdentifierKey]
-    file_uttype = UTType.typeWithIdentifier_(file_type)
-    uti_target = UTType.typeWithIdentifier_(uti)
-    if file_uttype.conformsToType_(uti_target):
-        return True
-    return False
+    """Return True if file at path conforms to UTI"""
+    return conforms_to_uti(uti_for_path(path), uti)
 
 
 @cache
